@@ -22,7 +22,7 @@ our @EXPORT_OK = qw(
                        wrap
                );
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 sub mbswidth {
     Unicode::GCString->new($_[0])->columns;
@@ -239,8 +239,14 @@ sub _wrap {
                     while (1) {
                         if ($is_cjk) {
                             # CJK word can be broken
-                            my $res = mbtrunc($word, $width - $x, 1);
-                            push @res, $res->[0];
+                            my $res;
+                            if ($prev_ws_after) {
+                                $res = mbtrunc($word, $width - $x - 1, 1);
+                                push @res, " ", $res->[0];
+                            } else {
+                                $res = mbtrunc($word, $width - $x, 1);
+                                push @res, $res->[0];
+                            }
                             my $word2 = substr($word, length($res->[0]));
                             #say "D:truncated CJK word: $word -> $res->[0] & $res->[1], remaining=$word2";
                             $word = $word2;
@@ -392,7 +398,7 @@ Text::WideChar::Util - Routines for text containing wide characters
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
